import { AlphabetLowercase, AlphabetUppercase } from './alphabet';
export interface DefaultContext<T> {
    options: IOptionFlag<T>;
    flags: {
        [k: string]: string;
    };
}
export interface IFlagBase<T, I> {
    name: string;
    char?: AlphabetLowercase | AlphabetUppercase;
    description?: string;
    hidden?: boolean;
    required?: boolean;
    parse(input: I): T;
}
export interface IBooleanFlag<T> extends IFlagBase<T, boolean> {
    type: 'boolean';
    allowNo: boolean;
}
export interface IOptionFlag<T> extends IFlagBase<T, string> {
    type: 'option';
    optionType: string;
    default?: T | ((context: DefaultContext<T>) => T | undefined);
    multiple: boolean;
    input: string[];
}
export interface Definition<T> {
    (options: {
        multiple: true;
    } & Partial<IOptionFlag<T>>): IOptionFlag<T[]>;
    (options: {
        required: true;
    } & Partial<IOptionFlag<T>>): IOptionFlag<T>;
    (options?: Partial<IOptionFlag<T>>): IOptionFlag<T | undefined>;
}
export interface EnumFlagOptions<T> extends Partial<IOptionFlag<T>> {
    options: string[];
}
export declare type IFlag<T> = IBooleanFlag<T> | IOptionFlag<T>;
export declare function build<T>(defaults: {
    parse: IOptionFlag<T>['parse'];
} & Partial<IOptionFlag<T>>): Definition<T>;
export declare function build(defaults: Partial<IOptionFlag<string>>): Definition<string>;
export declare function boolean<T = boolean>(options?: Partial<IBooleanFlag<T>>): IBooleanFlag<T>;
export declare const integer: Definition<number>;
declare const _enum: <T = string>(opts: EnumFlagOptions<T>) => Definition<T>;
export { _enum as enum };
export declare function option<T>(options: {
    parse: IOptionFlag<T>['parse'];
} & Partial<IOptionFlag<T>>): IOptionFlag<T | undefined>;
declare const stringFlag: Definition<string>;
export { stringFlag as string };
export declare const defaultFlags: {
    color: IBooleanFlag<boolean>;
};
export interface Output {
    [name: string]: any;
}
export declare type Input<T extends Output> = {
    [P in keyof T]: IFlag<T[P]>;
};
